@@ -2,6 +2,7 @@
 # Github: http://www.github.com/jasmcaus
 
 # Importing the necessary packages
+import os
 import numpy as np
 from .utils import readToGray
 from .utils import saveNumpy
@@ -41,8 +42,8 @@ def preprocess(DIR, categories, resized_size, size, name, isSave=True):
         # Shuffling the Training Set
         train = shuffle(train)
 
-        # # Converting to Numpy handled by saveNumpy()
-        # train = np.array(train)
+        # Converting to Numpy
+        train = np.array(train)
 
         # Saves the Train set as a .npy file
         if isSave == True:
@@ -75,7 +76,7 @@ def sepTrain(train, IMG_SIZE=224, channels=1):
 
     # Without reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE)
     # On reshaping, X.shape --> (no. of images, IMG_SIZE, IMG_SIZE,channels)
-    
+
     # Converting to Numpy + Reshaping X
     x = reshape(x, IMG_SIZE, channels)
     y = np.array(y)
@@ -90,4 +91,5 @@ def normalize(x):
     Normalizes the data to mean 0 and standard deviation 1
     """
     x = x/255.0
-    return x
\ No newline at end of file
+    return x
+    
\ No newline at end of file
